==> horreum-0.12.1-py3-none-any.whl: horreum/raw_client/api/dataset/list_/item/with_test_item_request_builder.py <==
from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .....models.dataset_list import DatasetList
    from .....models.sort_direction import SortDirection

class WithTestItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /api/dataset/list/{testId}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new WithTestItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/api/dataset/list/{testId}{?direction*,filter*,limit*,page*,sort*,viewId*}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration] = None) -> Optional[DatasetList]:
        """
        Retrieve a paginated list of Datasets, with total count, by Test
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[DatasetList]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .....models.dataset_list import DatasetList

        return await self.request_adapter.send_async(request_info, DatasetList, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration] = None) -> RequestInformation:
        """
        Retrieve a paginated list of Datasets, with total count, by Test
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def with_url(self,raw_url: Optional[str] = None) -> WithTestItemRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: WithTestItemRequestBuilder
        """
        if not raw_url:
            raise TypeError("raw_url cannot be null.")
        return WithTestItemRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class WithTestItemRequestBuilderGetQueryParameters():
        """
        Retrieve a paginated list of Datasets, with total count, by Test
        """
        def get_query_parameter(self,original_name: Optional[str] = None) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if not original_name:
                raise TypeError("original_name cannot be null.")
            if original_name == "view_id":
                return "viewId"
            if original_name == "direction":
                return "direction"
            if original_name == "filter":
                return "filter"
            if original_name == "limit":
                return "limit"
            if original_name == "page":
                return "page"
            if original_name == "sort":
                return "sort"
            return original_name
        
        # Sort direction
        direction: Optional[SortDirection] = None

        # JOSN Filter expression to apply to query
        filter: Optional[str] = None

        # limit the number of results
        limit: Optional[int] = None

        # filter by page number of a paginated list of Schemas
        page: Optional[int] = None

        # Field name to sort results
        sort: Optional[str] = None

        # Optional View ID to filter datasets by view
        view_id: Optional[int] = None

==> horreum-0.18-py3-none-any.whl: horreum/raw_client/api/dataset/list_/item/with_test_item_request_builder.py <==
from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .....models.dataset_list import DatasetList
    from .....models.sort_direction import SortDirection

class WithTestItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /api/dataset/list/{testId}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new WithTestItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/api/dataset/list/{testId}{?direction*,filter*,limit*,page*,sort*,viewId*}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[WithTestItemRequestBuilderGetQueryParameters]] = None) -> Optional[DatasetList]:
        """
        Retrieve a paginated list of Datasets, with total count, by Test
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[DatasetList]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .....models.dataset_list import DatasetList

        return await self.request_adapter.send_async(request_info, DatasetList, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[WithTestItemRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        Retrieve a paginated list of Datasets, with total count, by Test
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def with_url(self,raw_url: str) -> WithTestItemRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: WithTestItemRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return WithTestItemRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class WithTestItemRequestBuilderGetQueryParameters():
        """
        Retrieve a paginated list of Datasets, with total count, by Test
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "view_id":
                return "viewId"
            if original_name == "direction":
                return "direction"
            if original_name == "filter":
                return "filter"
            if original_name == "limit":
                return "limit"
            if original_name == "page":
                return "page"
            if original_name == "sort":
                return "sort"
            return original_name
        
        # Sort direction
        direction: Optional[SortDirection] = None

        # JOSN Filter expression to apply to query
        filter: Optional[str] = None

        # limit the number of results
        limit: Optional[int] = None

        # filter by page number of a paginated list of Schemas
        page: Optional[int] = None

        # Field name to sort results
        sort: Optional[str] = None

        # Optional View ID to filter datasets by view
        view_id: Optional[int] = None

    
    @dataclass
    class WithTestItemRequestBuilderGetRequestConfiguration(RequestConfiguration[WithTestItemRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
